@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'json'
 require 'rest-client'
 
@@ -28,7 +30,7 @@ module Kubeclient
         uri,
         '/api',
         version,
-        options
+        **options
       )
     end
   end
