@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # TODO: remove this on next major version bump
 # Deprected http exception
 class KubeException < StandardError
@@ -12,7 +14,7 @@ class KubeException < StandardError
   def to_s
     string = "HTTP status code #{@error_code}, #{@message}"
     if @response.is_a?(RestClient::Response) && @response.request
-      string << " for #{@response.request.method.upcase} #{@response.request.url}"
+      string += " for #{@response.request.method.upcase} #{@response.request.url}"
     end
     string
   end
